Option Explicit

' Esensors EM01B Websensor VBScript Plugin
' Mainly written for GFI, but easily adaptable to other applications
' Copyright 2006 Esensors, Inc. All rights reserved.
' Last Revision: 3:26 PM 11/21/2006 by Kenny Chow
' Version 1.0
' Usage: 
' call  check_em01(websensor, sensorType, lowLimit, highLimit)
' where parameters:	websensor - IP or hostname of Websensor
'				sensorType - The type of sensor to check.
'						 Valid values are: T, H, I and X
'						 T for Temperature
'						 H for Humidity
'						 I for Illumination
'						 X for Don't Care, doesn't check for threshold. 
'							Just return all values.
'				lowLimit - The lower treshold for the sensor.
'						Once value is lower than this, return False
'				highLimit - The higher treshold for the sensor.
'						Once value is higher than this, return False
' Example:  call check_em01("192.168.254.102", "T", 50.2, 80.5)
' 
' Note: A Monitor function can return True, False or Unknown
' True and False are already defined by Visual Basic Engine
' Define the Unknown return value. This value can be any value > 0

Const retvalUnknown = 1
dim EXPLANATION


Function check_em01(websensor, cmd, lowLimit, highLimit)
	Dim conn 
	
	Dim strTmp 
	Dim strTF
	Dim strHU
	Dim strIL 
	Dim intTmp1
	Dim strRcvEM01
	dim url
	dim xmlhttp
	On Error Resume Next	
    url = "http://" & websensor & "/index.html?em" 
	strRcvEM01 = ""
    'Create XMLHTTP/WinHttprequest object
	'You can use any of these objects.
	'Set xmlhttp = CreateObject("WinHttp.WinHttprequest.5")
	Set xmlhttp = CreateObject("MSXML2.XMLHTTP")

    xmlhttp.open "GET", url, false 
    xmlhttp.send "" 
	strRcvEM01 = xmlhttp.responseText
	set xmlhttp = nothing
	
	if strRcvEM01 <> "" Then
	    intTmp1 = 64
	    strTF = CDbl(Mid(strRcvEM01, intTmp1, 5))
	    strHU = CDbl(Mid(strRcvEM01, intTmp1 + 8, 4))
	    strIL = CDbl(Mid(strRcvEM01, intTmp1 + 16, 5))
		
		Select Case cmd
		Case "T"
			if strTF < lowLimit then
				EXPLANATION = "(FAIL) Temperature " & strTF & " is lower than Low Limit " & lowLimit
				check_em01 = False
			elseif strTF > highLimit then
				EXPLANATION = "(FAIL) Temperature " & strTF & " is higher than High Limit " & highLimit
				check_em01 = False
			else
				EXPLANATION = "(OK) Temperature " & strTF & " is within range"
				check_em01 = True
			end if
		Case "H"
			if strHU < lowLimit then
				EXPLANATION = "(FAIL) Humidity " & strHU & " is lower than Low Limit " & lowLimit
				check_em01 = False
			elseif strHU > highLimit then
				EXPLANATION = "(FAIL) Humidity " & strHU & " is higher than High Limit " & highLimit
				check_em01 = False
			else
				EXPLANATION = "(OK) Humidity " & strHU & " is within range"
				check_em01 = True
			end if
		Case "I"
			if strIL < lowLimit then
				EXPLANATION = "(FAIL) Illumination " & strIL & " is lower than Low Limit " & lowLimit
				check_em01 = False
			elseif strIL > highLimit then
				EXPLANATION = "(FAIL) Illumination " & strIL & " is higher than High Limit " & highLimit
				check_em01 = False
			else
				EXPLANATION = "(OK) Illumination " & strIL & " is within range"
				check_em01 = True
			end if			
		Case Else
				EXPLANATION = "EM01 Temperature (F): " & strTF & "      Humidity: " _
	            & strHU & "      Illumination: " & strIL
				check_em01 = True
		End Select	
    Else
        EXPLANATION = "Unable to connect to Websensor"
		check_em01 = retvalUnknown
    End If
End Function
msgbox check_em01("192.168.254.102", "T", 10, 100)
msgbox EXPLANATION